[![Build Status](https://travis-ci.org/dilawar/ajgar.svg?branch=master)](https://travis-ci.org/dilawar/ajgar) [![PyPI version](https://badge.fury.io/py/dilawar.svg)](https://badge.fury.io/py/dilawar)
# ajgar

Some helper utilities in Python
